/*
 *  Copyright (c) Members of the EGEE Collaboration. 2005.
 *  See http://eu-egee.org/partners/ for details on the copyright holders.
 *  For license conditions see the license file or http://eu-egee.org/license.html
 *
 *  gLite Security Delegation Clients - Get Proxy
 *
 *  Authors: Zoltan Farkas <Zoltan.Farkas@cern.ch>
 *
 */

#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

#include <glite/data/delegation/c/delegation-simple.h>

#include "delegation-main.h"

#include <stdlib.h>
#include <stdio.h>

/**********************************************************************
 * Global variables
 */

/* Usage message */
const char *tool_usage = "[DELEGATION_ID]";

/* Help message */
const char *tool_help = 
	"\t-e TIME\t\tSet expiration time in minutes\n";

/* getguid-specific command line options */
const char *tool_options = "e:f";

/* Expiration time in minutes, default to one day */
static int exp_time = 60*24;

/* If the delegation is to be forced, even when there is a valid credential. */
static int force_delegation = 0;

/**********************************************************************
 * Tool implementation
 */

int tool_doit(glite_delegation_ctx *ctx, int argc, char *argv[])
{
	int ret;
	char *delegation_id;
	
	delegation_id = (argc ? argv[0] : "");
    
    if (force_delegation) 
        info("Warning: forcing the delegation!");

	ret = glite_delegation_delegate(ctx, delegation_id, exp_time, force_delegation);
	if (-1 == ret)
	{
		error("Error: %s", glite_delegation_get_error(ctx));
		return -1;
	}

    info("The credential is delegated [%s]\n", delegation_id);
	return 0;
}

/**********************************************************************
 * Command line parsing
 */

int tool_parse_cmdline(int c, char *opt_arg)
{
	switch (c)
	{
		case 'e':
			if (!sscanf(opt_arg, "%d", &exp_time))
				return -1;
			return 0;
        case 'f':
            force_delegation = 1;
            return 0;
		default:
			return -1;
	}				
	return -1;
}
