#!/bin/bash
#
# Copyright (c) Members of the EGEE Collaboration. 2004.
# See http://public.eu-egee.org/partners/ for details on 
# the copyright holders.
# For license conditions see the license file or
# http://eu-egee.org/license.html
#
# Authors: 
#      Akos Frohner <Akos.Frohner@cern.ch>
#

TEST_MODULE='org.glite.data.delegation-cli'
TEST_REQUIRES='glite-delegation-destroy glite-delegation-init glite-delegation-info voms-proxy-info'

if [ -z "$GLITE_LOCATION" ]; then
    GLITE_LOCATION=$(dirname $0)/../../stage
fi
source $GLITE_LOCATION/share/test/glite-data-util-c/shunit

ENDPOINT='https://localhost:8443/glite-security-delegation-service-java/services/gridsite-delegation'

test_success 'Endpoint: http.*://localhost:8.*/glite-security-delegation-service-java' \
    glite-sd-query -t org.glite.Delegation

function test_zero {
    # just to clean up the service, in case there is already a delegated credential
    # it is expected to fail, but it will do it quietly...
    glite-delegation-destroy -q
    test_success 'credential is delegated' glite-delegation-init -v
    glite-delegation-destroy -q
}

function test_basic {
    # just to clean up the service, in case there is already a delegated credential
    # it is expected to fail, but it will do it quietly...
    glite-delegation-destroy -q

    test_success 'credential is delegated' glite-delegation-init -v

    test_failure 'Error.*already exists'   glite-delegation-init -v

    # forcing should come over temporary problems
    test_success 'credential is delegated' glite-delegation-init -v -f

    test_success 'has been destroyed'      glite-delegation-destroy -v

    # start cleanly
    test_success 'credential is delegated' glite-delegation-init -v

    test_success 'Expiration time of '     glite-delegation-info -v
}

function test_33641 {
    # just to clean up the service, in case there is already a delegated credential
    # it is expected to fail, but it will do it quietly...
    glite-delegation-destroy -q

    test_success 'credential for B is delegated' test-glite-delegation-bug-33641 -v -f

    test_success 'Expiration time of '     glite-delegation-info -v

    test_success 'has been destroyed'      glite-delegation-destroy -v
}

function test_fs {
    store=/tmp/dlgee_delegationStorage
    if [ -d "$store" ]; then
        echo "========================================"
        echo " Testing the filesystem backend directly"
        echo "========================================"

        # comparing the storage with reality
        echo "Checking the current certificate for VOMS attributes"
        test_success 'attribute : /org.acme'   voms-proxy-info -all

        subject_clear="/C=UG/L=Tropic/O=Utopia/OU=Relaxation/CN=$LOGNAME"
        subject_urlenc="C%3DUG%2CL%3DTropic%2CO%3DUtopia%2COU%3DRelaxation%2CCN%3D$LOGNAME"
        storedir=$(ls -d $store/$subject_urlenc/* | head -1)
        proxy=$storedir/userproxy.pem

        echo "Checking the current certificate for VOMS attributes"
        test_success 'attribute : /org.acme'   voms-proxy-info -file $proxy -all
        test_success '/org.acme' cat $storedir/voms.attributes

        test_success '/C=UG/L=Tropic/O=Utopia/OU=Relaxation' \
            openssl x509 -in $proxy -noout -subject

        echo ""
        dtimeraw=$(glite-delegation-info -q)
        dtime=$(date --utc +%Y-%m-%dT%H:%M:%S --date="$dtimeraw")
        echo "Info: expiration time, according to the service: $dtime ($dtimeraw)"

        ptimeraw=$(openssl x509 -in $proxy -noout -enddate)
        ptime=$(date --utc +%Y-%m-%dT%H:%M:%S --date="${ptimeraw:9}")
        echo "Info: expiration time of the delegated proxy: $ptime ($ptimeraw)"

        ftimeraw=$(cat $storedir/termination.time)
        ftime=$(date --utc +%Y-%m-%dT%H:%M:%S --date="$ftimeraw")
        echo "Info: expiration time in the storage: $ftime ($ftimeraw)"

        test_success $ptime echo $dtime
        test_success $ptime echo $ftime
        test_success $ftime echo $dtime
    fi # end of FS-back-end test
}

function test_second {
    echo ""
    echo "A second delegation using the 'Second' ID:"
    test_success 'credential is delegated' glite-delegation-init -v Second
    test_success 'has been destroyed'      glite-delegation-destroy -v Second

    test_success 'has been destroyed'      glite-delegation-destroy -v
}

#test_zero
test_basic
test_second
test_33641
#test_fs

test_summary
